==> isoquery_1.4.orig.tar.bz2: isoquery-1.4/isoquery/xmlfile_3166_2.py <==
# - encoding: UTF-8 -
#
# Copyright © 2007-2010 Tobias Quathamer
#
# This file is part of isoquery.
#
# isoquery is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# isoquery is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import sys
import gettext
translation = gettext.translation('isoquery', fallback=True)
_ = translation.ugettext
from lxml import etree
import xmlfile
from code_not_defined_error import CodeNotDefinedError

class XMLFile_3166_2(xmlfile.XMLFile):
    """Handle ISO 3166-2"""
    def get_display_codes(self):
        """Return a list of code attributes"""
        return ["country", "type", "code", "parent"]

    def get_display_names(self, display_name):
        """Return a list of possible name attributes.
        
        If the first attribute is not found, the next one in the list
        will be tried. This is to enable official_name and
        common_name in ISO 3166, other standards don't need this."""
        return ["name"]

    def get_xpaths(self, code):
        """Return a list of all xpaths needed to show the requested codes"""
        xpaths = []
        xpath = "//iso_3166_2_entry[@code='" + code.upper() + "']"
        xpaths.append(xpath)
        return xpaths

    def display_entry(self, entry):
        """Add attributes to the entry before displaying.
        
        In this step, the country and subset type of the ISO 3166-2 entry
        are added to the attributes. This is to enable the method of the
        base class to use them for displaying, without needing to dive
        deep into the nested constructs of this particular XML file."""
        # Add the country's code
        country_code = entry.getparent().getparent().get("code")
        entry.set("country", country_code)
        # Add subset type (e.g. State, District, Province, etc.)
        # As this is a required attribute, it should always exist.
        subset_type = entry.getparent().get("type")
        entry.set("type", subset_type)
        # Call the base method for actual display
        xmlfile.XMLFile.display_entry(self, entry)

==> isoquery_1.5.orig.tar.bz2: isoquery-1.5/isoquery/xmlfile_639_3.py <==
# - encoding: UTF-8 -
#
# Copyright © 2007-2011 Tobias Quathamer
#
# This file is part of isoquery.
#
# isoquery is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# isoquery is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import sys
import gettext
translation = gettext.translation('isoquery', fallback=True)
_ = translation.ugettext
from lxml import etree
import xmlfile
from code_not_defined_error import CodeNotDefinedError

class XMLFile_639_3(xmlfile.XMLFile):
    """Handle ISO 639-3"""
    def get_display_codes(self):
        """Return a list of code attributes"""
        return ["id", "scope", "type", "part1_code", "part2_code"]

    def get_display_names(self, display_name):
        """Return a list of possible name attributes.
        
        If the first attribute is not found, the next one in the list
        will be tried. This is to enable official_name and
        common_name in ISO 3166, other standards don't need this."""
        return ["name"]

    def get_xpaths(self, code):
        """Return a list of all xpaths needed to show the requested codes"""
        xpaths = []
        if (len(code) == 1):
            xpath = "//iso_639_3_entry[@scope='" + code.upper() + "']"
            xpaths.append(xpath)
            xpath = "//iso_639_3_entry[@type='" + code.upper() + "']"
        elif (len(code) == 2):
            xpath = "//iso_639_3_entry[@part1_code='" + code.lower() + "']"
        else:
            xpath = "//iso_639_3_entry[@id='" + code.lower() + "']"
            xpaths.append(xpath)
            xpath = "//iso_639_3_entry[@part2_code='" + code.lower() + "']"
        xpaths.append(xpath)
        return xpaths
